@@ -73,6 +73,7 @@
 #include "style.h"
 #include "move_resize.h"
 #include "menus.h"
+#include "infostore.h"
 #ifdef HAVE_STROKE
 #include "stroke.h"
 #endif /* HAVE_STROKE */
@@ -1185,14 +1186,12 @@ static
 void update_decors_colorset(int cset)
 {
 	int i;
-	int has_changed;
 	FvwmDecor *decor = &Scr.DefaultDecor;
 
 #ifdef USEDECOR
 	for(decor = &Scr.DefaultDecor; decor != NULL; decor = decor->next)
 #endif
 	{
-		has_changed = 0;
 		for(i = 0; i < NUMBER_OF_TITLE_BUTTONS; i++)
 		{
 			decor->flags.has_changed |= update_titlebutton_colorset(
@@ -2722,6 +2721,10 @@ void CMD_PrintInfo(F_CMD_ARGS)
 	{
 		print_bindings();
 	}
+	else if (StrEquals(subject, "InfoStore"))
+	{
+		print_infostore();
+	}
 	else
 	{
 		fvwm_msg(ERR, "PrintInfo",
@@ -3150,7 +3153,6 @@ void CMD_WindowFont(F_CMD_ARGS)
 void CMD_ChangeDecor(F_CMD_ARGS)
 {
 	char *item;
-	int old_height;
 	FvwmDecor *decor = &Scr.DefaultDecor;
 	FvwmDecor *found = NULL;
 	FvwmWindow * const fw = exc->w.fw;
@@ -3175,7 +3177,6 @@ void CMD_ChangeDecor(F_CMD_ARGS)
 		return;
 	}
 	SET_DECOR_CHANGED(fw, 1);
-	old_height = (fw->decor) ? fw->decor->title_height : 0;
 	fw->decor = found;
 	apply_decor_change(fw);
 
