@@ -764,6 +764,9 @@ InstallSignals(void)
 	sigaction(SIGQUIT, &sigact, NULL);
 	sigaction(SIGTERM, &sigact, NULL);
 
+	/* Unblock these signals so that we can process them again. */
+	sigprocmask(SIG_UNBLOCK, &sigact.sa_mask, NULL);
+
 	/* Reap all zombies automatically! This signal handler will only be
 	 * called if a child process dies, not if someone sends a child a STOP
 	 * signal. Note that none of our "terminate" signals can be delivered
@@ -1073,7 +1076,6 @@ static void CreateGCs(void)
 {
 	XGCValues gcv;
 	unsigned long gcm;
-	XColor c;
 
 	/* create scratch GC's */
 	gcm = GCFunction|GCLineWidth;
@@ -1087,7 +1089,6 @@ static void CreateGCs(void)
 	Scr.TitleGC = fvwmlib_XCreateGC(dpy, Scr.NoFocusWin, gcm, &gcv);
 	Scr.BordersGC = fvwmlib_XCreateGC(dpy, Scr.NoFocusWin, gcm, &gcv);
 	Scr.TransMaskGC = fvwmlib_XCreateGC(dpy, Scr.NoFocusWin, gcm, &gcv);
-	c.pixel = GetColor(DEFAULT_FORE_COLOR);
 	Scr.ScratchMonoPixmap = XCreatePixmap(dpy, Scr.Root, 1, 1, 1);
 	Scr.MonoGC = fvwmlib_XCreateGC(dpy, Scr.ScratchMonoPixmap, gcm, &gcv);
 	Scr.ScratchAlphaPixmap = XCreatePixmap(
@@ -1384,11 +1385,14 @@ static void SetRCDefaults(void)
 		{ "TitleStyle Centered -- Raised", "", "" },
 		{ "Style * Color lightgrey/dimgrey", "", "" },
 		{ "Style * HilightFore black, HilightBack grey", "", "" },
+		{ "DestroyFunc FvwmMakeMissingDesktopMenu", "", "" },
+		{ "AddToFunc   FvwmMakeMissingDesktopMenu I PipeRead 'fvwm-menu-desktop --enable-mini-icons --fvwm-icons'", "", "" },
 		{
 			"AddToMenu MenuFvwmRoot \"",
 			_("Builtin Menu"),
 			"\" Title"
 		},
+                { "+ MissingSubmenuFunction FvwmMakeMissingDesktopMenu","",""},
 		{ "+ \"&1. XTerm\" Exec xterm", "", ""},
 		{
 			"+ \"&2. ",
@@ -1429,7 +1433,6 @@ static void SetRCDefaults(void)
 		{ "Key Up M A MenuMoveCursor -1", "", "" },
 		{ "Key Down M A MenuMoveCursor 1", "", "" },
 		{ "Mouse 1 MI A MenuSelectItem", "", "" },
-		{ "PipeRead 'fvwm-menu-desktop --enable-mini-icons --fvwm-icons'", "", "" },
 		/* don't add anything below */
 		{ RC_DEFAULTS_COMPLETE, "", "" },
 		{ "Read "FVWM_DATADIR"/ConfigFvwmDefaults", "", "" },
